@@ -19,10 +19,10 @@ void displayDoc(const QString &url, const QString &title)
     qputenv("HOME", starting_home.toUtf8());
     // prefer mx-viewer otherwise use xdg-open (use runuser to run that as logname user) "gio open" would also work here
     if (QFile::exists(QStringLiteral("/usr/bin/mx-viewer"))) {
-        QProcess::execute(QStringLiteral("mx-viewer"), {url, title});
+        QProcess::startDetached(QStringLiteral("mx-viewer"), {url, title});
     } else {
         if (getuid() != 0) {
-            QProcess::execute(QStringLiteral("xdg-open"), {url});
+            QProcess::startDetached(QStringLiteral("xdg-open"), {url});
             return;
         } else {
             QProcess proc;
